0.6 (2021-11-06)
----------------

- Fix `rounds-limit` message
- Fix checkin on round limits


0.5 (2021-10-24)
----------------

- Add self-registration for players
- Add the possibility to limit the nuumber of rounds


0.4 (2021-09-28)
----------------

- Fixed judge checkin
- Improved archon help: now display judges commands in the judges channel only
- Fixed round-add


0.3 (2021-09-26)
----------------

- Players list fixed: only checked-in players are now displayed


0.2 (2021-07-07)
----------------

- Fix main


0.1 (2021-07-07)
----------------

- First public version
